@@ -6,7 +6,6 @@
 
 #include <KOpeningHours/Display>
 #include <KOpeningHours/Interval>
-#include <KOpeningHours/IntervalModel>
 #include <KOpeningHours/OpeningHours>
 
 #include <QCoreApplication>
@@ -38,15 +37,6 @@ OpeningHours OpeningHoursFactory::parse(const QString &expression, int modes) co
 
 void KOpeningHoursQmlPlugin::registerTypes(const char*)
 {
-    qRegisterMetaType<KOpeningHours::Interval>();
-    qRegisterMetaType<KOpeningHours::OpeningHours>();
-    qRegisterMetaType<KOpeningHours::OpeningHours::Modes>();
-
-    qmlRegisterUncreatableMetaObject(KOpeningHours::Interval::staticMetaObject, "org.kde.kopeninghours", 1, 0, "Interval", {});
-    qmlRegisterUncreatableMetaObject(KOpeningHours::OpeningHours::staticMetaObject, "org.kde.kopeninghours", 1, 0, "OpeningHours", {});
-
-    qmlRegisterType<KOpeningHours::IntervalModel>("org.kde.kopeninghours", 1, 0, "IntervalModel");
-
     // HACK qmlplugindump chokes on gadget singletons, to the point of breaking ecm_find_qmlmodule()
     if (QCoreApplication::applicationName() != QLatin1String("qmlplugindump")) {
         qmlRegisterSingletonType("org.kde.kopeninghours", 1, 0, "OpeningHoursParser", [](QQmlEngine*, QJSEngine *engine) -> QJSValue {
